monty
=====

[![Build Status](https://travis-ci.org/materialsvirtuallab/monty.png?branch=master)](https://travis-ci.org/materialsvirtuallab/monty)

Monty implements supplementary useful functions for Python that are
not part of the standard library. Examples include useful utilities like
transparent support for zipped files, useful design patterns such as
singleton and cached_class, and many more.

Please read the [official docs](https://www.pythonhosted.org/monty)